@@ -122,7 +122,7 @@ def create_event( type:str,
 
 def validate_event(eventType , detail):
 
-    SCHEMA_FILE = os.path.join(os.path.dirname(__file__),"schema/{}.json".format(eventType))
+    SCHEMA_FILE = os.path.join(os.path.dirname(__file__),"data/{}.json".format(eventType))
 
     with open(SCHEMA_FILE) as fs:
         schema =  json.load(fs)
